fmt

Attribute Macro fmt 

#[fmt]
Specify Rust format flags to use when rendering a property in a template.

Syntax

fmt_string

where

  • fmt_string: A string literal with the format flags, like ":?". See the std::fmt docs for details on available flags.

Applicable to

This attribute can be applied to properties that appear in a template.