optional

Attribute Macro optional 

#[optional]
Specify that a property value of None should not be captured, instead of being captured as null.

Syntax

This macro doesn’t accept any arguments.

Applicable to

This attribute can be applied to properties where the type is Option<&T>.