Module clock

Module clock 

The Clock type.

A clock is a service that returns a Timestamp representing the current point in time. Clock readings are not guaranteed to be monotonic. They may move forwards or backwards arbitrarily, but for diagnostics to be useful, a clock should strive for accuracy.

Traits

Clock
A service to get the current Timestamp.
ErasedClock
An object-safe Clock.