Module kind

Module kind 

The Kind type.

Structs

KindFilter
A Filter that matches events with a specific Kind.
ParseKindError
An error attempting to parse a Kind from text.

Enums

Kind
A kind of specialized diagnostic event.

Functions

is_metric
Test whether an event is a metric sample.
is_metric_filter
Only match events that are metric samples.
is_span
Test whether an event is a span in a distributed trace.
is_span_filter
Only match events that are spans in a distributed trace.