Module level

Module level 

The Level type.

Structs

MinLevelFilter
A Filter that matches events with a specific Level.
MinLevelPathMap
A filter that applies a MinLevelFilter based on the module of an event.
ParseLevelError
An error attempting to parse a Level from text.

Enums

Level
A severity level for a diagnostic event.

Functions

min_by_path_filter
Construct a set of MinLevelFilters that are applied based on the module of an event.
min_filter
Only match events that carry the given Level.