BucketSet

Struct BucketSet 

pub struct BucketSet { /* private fields */ }
A collection for buckets in an exponential histogram.

The set stores sparse, sorted buckets as a tuple of their midpoint (Point), and count of occurrences.

Implementations

Source

impl BucketSet

pub fn new() -> Self

Create a new empty BucketSet.

This method does not allocate.

pub fn try_from_str(s: &str) -> Result<Self, ParseBucketSetError>

Parse a BucketSet from its raw textual representation.

pub fn observe(&mut self, value: Point)

Observe a Point computed from a raw value.

The count for this point will be incremented by 1.

All points should be computed from the same scale.

Panics

This method will panic if adding count to an existing entry in value would overflow.

pub fn observe_all(&mut self, value: Point, count: u64)

Observe count instances of a Point computed from a raw value.

The count for this point will be incremented by count.

All points should be computed from the same scale.

Panics

This method will panic if adding count to an existing entry in value would overflow.

pub fn remap(&mut self, map: impl FnMut(Point) -> Point)

Remap and merge buckets.

This method can be used to rescale the buckets to a coarser granularity in combination with the crate::metric::exp::midpoint function. It accepts a closure that maps stored bucket Points to new values. When multiple buckets map to the same new value, their counts will be summed.

Panics

This method will panic if adding count to an existing entry in value would overflow. This can happen when merging buckets with large counts.

pub fn len(&self) -> usize

Get the number of buckets currently in the set.

This is not the total count of observed values in all buckets, just the count of buckets themselves. See BucketSet::total for the total count.

pub fn total(&self) -> u64

Get the total count of observed values.

pub fn clear(&mut self)

Clear all buckets, allowing the allocation to be re-used.

pub fn get(&self, value: Point) -> Option<u64>

Get the count for a particular bucket.

pub fn first(&self) -> Option<(Point, u64)>

Get the first (lowest numbered) bucket.

pub fn last(&self) -> Option<(Point, u64)>

Get the last (highest numbered) bucket.

pub fn iter(&self) -> Iter<'_>

Iterate over buckets in order.