emit

Module path

The Path type.

A path is a hierarchical identifier with fragments separated by ::. Simple Rust paths like a, and a::b::c are valid Paths. Complex Rust paths like a::{b, c}, and a::* are not valid Paths.

Paths are used to represent the module on crate::event::Events.

Structs

Functions