emit::platform::thread_local_ctxt

Struct ThreadLocalCtxt

pub struct ThreadLocalCtxt { /* private fields */ }
A Ctxt that stores ambient state in thread local storage.

Frames fully encapsulate all properties that were active when they were created so can be sent across threads to move that state with them.

Implementations

Source

impl ThreadLocalCtxt

pub fn new() -> Self

Create a new thread local store with fully isolated storage.

pub const fn shared() -> Self

Create a new thread local store sharing the same storage as any other ThreadLocalCtxt::shared.