emit::runtime

Function internal

pub fn internal() -> &'static Runtime<&'static (dyn ErasedEmitter + Sync + Send), &'static (dyn ErasedFilter + Sync + Send), &'static (dyn ErasedCtxt + Sync + Send), &'static (dyn ErasedClock + Sync + Send), &'static (dyn ErasedRng + Sync + Send)>
The internal runtime for other runtime components to use.

Applications should use the shared() runtime instead of this one.

This runtime can be initialized through its internal_slot() to enable diagnostics on the regular diagnostics runtime itself.