Module span

Module span 

The Span type.

Re-exports

pub use self::completion::Completion;

Modules

completion
The Completion type.

Structs

ParseIdError
An error encountered attempting to parse a TraceId or SpanId.
ParseKindError
An error encountered attempting to parse a TraceId or SpanId.
ParseLinkError
An error encountered attempting to parse a TraceId or SpanId.
Span
A diagnostic event that represents a span in a distributed trace.
SpanCtxt
The trace id, span id, and parent span id of a span.
SpanGuard
An active span in a distributed trace.
SpanId
A W3C Span Id.
SpanLink
A link between two spans in potentially different traces.
TraceId
A W3C Trace Id.

Enums

SpanKind
A hint about the way a span and its child are linked.