SpanKind

Enum SpanKind 

#[non_exhaustive]
pub enum SpanKind { Internal, Server, Client, Producer, Consumer, }
A hint about the way a span and its child are linked.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Internal

Internal spans represent operations which do not cross a process boundary.



Server

Server-side handling of an RPC or other remote network request.

Paired with a Client.



Client

A request to some remote service.

Paired with a Server.



Producer

A producer sending a message to a broker.

Paired with a Consumer.



Consumer

A consumer receiving a message from a broker.

Paired with a Producer.

Implementations

Source

impl SpanKind

pub fn try_from_str(s: &str) -> Result<Self, ParseKindError>

Try parse a span kind from a formatted representation.

pub fn as_str(&self) -> &'static str

Get the value of the span kind as a string.