SpanLink

Struct SpanLink 

pub struct SpanLink { /* private fields */ }
A link between two spans in potentially different traces.

A link belongs to a span, and contains the TraceId and SpanId of the span being linked to. Links are usually created on the downstream span.

Links relate spans outside of the normal parent-child hierarchy. Links are largely informative and may not be understood by downstream consumers. In order to create a generic DAG out of span links, the spans would need to belong to separate traces, since the parent-child relationship is still required.

Implementations

pub const fn new(trace_id: TraceId, span_id: SpanId) -> Self

Create a new link to the target span.

pub fn try_from_str(s: &str) -> Result<Self, ParseLinkError>

Try parse a span link from a formatted representation.

pub fn parse(s: impl Display) -> Result<Self, ParseLinkError>

Try parse a span link from a formatted representation.

pub fn trace_id(&self) -> &TraceId

The TraceId of the linked span.

pub fn span_id(&self) -> &SpanId

The SpanId of the linked span.