emit

Struct Str

pub struct Str<'k> { /* private fields */ }
A string value.

The Str::get method can be used to operate on the value as if it’s a standard str. Equality, ordering, and hashing all defer to the str representation.

The value may internally be any one of:

  • &'k str.
  • &'static str.
  • Box<str>.
  • Arc<str>.

Implementations

Source

impl Str<'static>

pub const fn new(k: &'static str) -> Str<'static>

Create a new string from a value borrowed for 'static.

Source

impl<'k> Str<'k>

pub const fn new_ref(k: &'k str) -> Str<'k>

Create a new string from a value borrowed for 'k.

The Str::new method should be preferred where possible.

pub const fn by_ref<'b>(&'b self) -> Str<'b>

Get a new string, borrowing data from this one.

pub const fn get(&self) -> &str

Get a reference to the underlying value.

pub const fn get_static(&self) -> Option<&'static str>

Try get a reference to the underlying static value.

If the string was created from Str::new and contains a 'static value then this method will return Some. Otherwise this method will return None.

Source

impl Str<'static>

pub fn new_owned(key: impl Into<Box<str>>) -> Str<'static>

Create a string from an owned value.

Cloning the string will involve cloning the value.

pub fn new_shared(key: impl Into<Arc<str>>) -> Str<'static>

Create a string from a shared value.

Cloning the string will involve cloning the Arc, which may be cheaper than cloning the value itself.

Source

impl<'k> Str<'k>

pub fn new_cow_ref(key: Cow<'k, str>) -> Str<'k>

Create a string from a potentially owned value.

If the value is Cow::Borrowed then this method will defer to Str::new_ref. If the value is Cow::Owned then this method will defer to Str::new_owned.

pub fn to_cow(&self) -> Cow<'static, str>

Get the underlying value as a potentially owned string.

If the string contains a 'static value then this method will return Cow::Borrowed. Otherwise it will return Cow::Owned.

pub fn to_owned(&self) -> Str<'static>

Get a new string, taking an owned copy of the data in this one.

If the string contains a 'static or Arc value then this method is cheap and doesn’t involve cloning. In other cases the underlying value will be passed through Str::new_owned.

pub fn into_string(self) -> String

Convert this string into an owned String.

If the underlying value is already an owned string then this method will return it without allocating.

pub fn to_shared(&self) -> Str<'static>

Get a new string, taking an owned copy of the data in this one.

If the string contains a 'static or Arc value then this method is cheap and doesn’t involve cloning. In other cases the underlying value will be passed through Str::new_shared.