emit

Struct Template

pub struct Template<'a>(/* private fields */);
A lazily evaluated text template with named holes for interpolating properties into.

The Template::render method can be used to format a template with Props into a string or other representation.

Template equality is based on the equality of their renderings.

Two templates can be equal if they’d render to the same outputs. That means they must have the same holes in the same positions, but their text tokens may be split differently, so long as they produce the same text.

Implementations

Source

impl Template<'static>

pub const fn new(parts: &'static [Part<'static>]) -> Template<'static>

Create a template from a set of tokens.

pub const fn literal(text: &'static str) -> Template<'static>

Create a template from a string literal with no holes.

Source

impl<'a> Template<'a>

pub const fn new_ref(parts: &'a [Part<'a>]) -> Template<'a>

Create a template from a borrowed set of tokens.

The Template::new method should be preferred where possible.

pub const fn literal_ref(text: &'a str) -> Template<'a>

Create a template from a string literal with no holes.

The Template::literal method should be preferred where possible.

pub fn by_ref<'b>(&'b self) -> Template<'b>

Get a new template, borrowing data from this one.

pub fn as_literal(&self) -> Option<&Str<'a>>

Try get the value of the template as a string literal.

If the template only has a single token, and that token is text, then this method will return Some. Otherwise this method will return None.

pub fn parts(&self) -> Parts<'_, 'a>

Iterate over the parts of the template.

pub fn render<'b, P>(&'b self, props: P) -> Render<'b, P>

Lazily render the template, using the given properties for interpolation.

Source

impl Template<'static>

pub fn new_owned(parts: impl Into<Box<[Part<'static>]>>) -> Template<'static>

Create a template from a set of owned parts.

Source

impl<'a> Template<'a>

pub fn to_owned(&self) -> Template<'static>

Get a new template from this one, converting its parts into owned data.

If the template already contains owned data then this method will simply clone it.