Timestamp

Struct Timestamp 

pub struct Timestamp(/* private fields */);
A Unix timestamp with nanosecond precision.

Implementations

Source

impl Timestamp

pub const MIN: Timestamp

The minimum timestamp, 1970-01-01T00:00:00Z.

pub const MAX: Timestamp

The maximum timestamp, 9999-12-31T23:59:59.999999999Z.

pub fn from_unix(unix_time: Duration) -> Option<Timestamp>

Try create a timestamp from time since the Unix epoch.

If the unix_time is within Timestamp::MIN..=Timestamp::MAX then this method will return Some. Otherwise it will return None.

pub fn to_unix(&self) -> Duration

Get the value of the timestamp as time since the Unix epoch.

pub fn try_from_str(ts: &str) -> Result<Timestamp, ParseTimestampError>

Try parse a timestamp from an RFC3339 formatted representation.

pub fn parse(ts: impl Display) -> Result<Timestamp, ParseTimestampError>

Try parse a timestamp from an RFC3339 formatted value.

pub fn duration_since(self, earlier: Timestamp) -> Option<Duration>

Calculate the timespan between two timestamps.

This method will return None if earlier is actually after self.

pub fn from_system_time(ts: SystemTime) -> Option<Timestamp>

Convert a system timestamp into a timestamp.

If the ts is within Timestamp::MIN..=Timestamp::MAX then this method will return Some. Otherwise it will return None.

pub fn to_system_time(&self) -> SystemTime

Convert the timestamp into a system timestamp.

This method can be used for interoperability with code expecting a standard library timestamp.

pub fn from_parts(parts: Parts) -> Option<Timestamp>

Try get a timestamp from its individual date and time parts.

If the resulting timestamp is within Timestamp::MIN..=Timestamp::MAX then this method will return Some. If it’s outside then it will return None. If any of the fields in parts is out of range for its type, such as days: 32, then this method will also return None.

pub fn to_parts(&self) -> Parts

Get the individual date and time parts of the timestamp.

The returned parts are in exactly the form needed to display them. Months and days are both one-based.

pub fn checked_add(&self, rhs: Duration) -> Option<Timestamp>

Add a duration to this timestamp.

If the result would be greater than Timestamp::MAX then None is returned.

pub fn checked_sub(&self, rhs: Duration) -> Option<Timestamp>

Subtract a duration to this timestamp.

If the result would be less than Timestamp::MIN then None is returned.

pub fn checked_duration_since(&self, earlier: Timestamp) -> Option<Duration>

Get the duration between this timestamp and an earlier one.