OwnedValue

Struct OwnedValue 

pub struct OwnedValue(/* private fields */);
An owned Value that can be cloned and shared.

Owned values don’t expose much API of their own but can be cheaply converted back into a Value through OwnedValue::by_ref.

Implementations

Source

impl OwnedValue

pub fn by_ref<'v>(&'v self) -> Value<'v>

Get a Value, borrowing data from this one.