#[fmt]Expand description
Specify Rust format flags to use when rendering a property in a template.
Syntax
fmt_stringwhere
fmt_string: A string literal with the format flags, like":?". See thestd::fmtdocs for details on available flags.
Applicable to
This attribute can be applied to properties that appear in a template.