#[key]Expand description
Specify the key for a property.
Syntax
keywhere
key: A string literal with the key to use. The key doesn’t need to be a valid Rust identifier.
This macro can also be called with an explicit name identifier:
name: keywhere
key: An expression that evaluates to a string value for the key to use. The key doesn’t need to be a valid Rust identifier.
Applicable to
This attribute can be applied to properties.