#[optional]
Specify that a property value of None should not be captured, instead of being captured as null.
None
null
This macro doesn’t accept any arguments.
This attribute can be applied to properties where the type is Option<&T>.
Option<&T>