pub fn ctxt() -> AmbientCtxt<'static>Expand description
Get the shared context.
This method will use the Ctxt from runtime::shared().
The returned context can be used with Frames to manage the ambient state added to diagnostic events.
pub fn ctxt() -> AmbientCtxt<'static>Get the shared context.
This method will use the Ctxt from runtime::shared().
The returned context can be used with Frames to manage the ambient state added to diagnostic events.