The Kind type.
Structs
- Kind
Filter - A
Filterthat matches events with a specificKind. - Parse
Kind Error - An error attempting to parse a
Kindfrom text.
Enums
- Kind
- A kind of specialized diagnostic event.
Functions
- is_
metric - Test whether an event is a metric sample.
- is_
metric_ filter - Only match events that are metric samples.
- is_span
- Test whether an event is a span in a distributed trace.
- is_
span_ filter - Only match events that are spans in a distributed trace.