pub struct MinLevelFilter<L = Level> { /* private fields */ }Expand description
A Filter that matches events with a specific Level.
The level to match is pulled from the KEY_LVL well-known property. Events that don’t carry any specific level are treated as carrying a default one, as set by MinLevelFilter::treat_unleveled_as.
Implementations
Sourceimpl<L> MinLevelFilter<L>
impl<L> MinLevelFilter<L>
Sourcepub const fn new(min: L) -> MinLevelFilter<L>
pub const fn new(min: L) -> MinLevelFilter<L>
Construct a new MinLevelFilter, treating unleveled events as Level::default.
Sourcepub fn treat_unleveled_as(self, default: L) -> Self
pub fn treat_unleveled_as(self, default: L) -> Self
Treat events without an explicit level as having default when evaluating against the filter.