pub struct MinLevelPathMap<L = Level> { /* private fields */ }Expand description
A filter that applies a MinLevelFilter based on the module of an event.
This type allows different modules to apply different level filters. In particular, modules generating a lot of diagnostic noise can be silenced without affecting other modules.
Event modules are matched based on Path::is_child_of. If an event’s module is a child of one in the map then its MinLevelFilter will be checked against it. If an event’s module doesn’t match any in the map then it will pass the filter.
Implementations
Sourceimpl<L> MinLevelPathMap<L>
impl<L> MinLevelPathMap<L>
Sourcepub fn default_min_level(
&mut self,
min_level: impl Into<MinLevelFilter<L>>,
) -> &mut Self
pub fn default_min_level( &mut self, min_level: impl Into<MinLevelFilter<L>>, ) -> &mut Self
Specify the minimum level for any modules that don’t match any added by MinLevelPathMap::min_level.