pub struct BucketSet { /* private fields */ }Expand description
A collection for buckets in an exponential histogram.
The set stores sparse, sorted buckets as a tuple of their midpoint (Point), and count of occurrences.
Implementations
Sourceimpl BucketSet
impl BucketSet
Sourcepub fn try_from_str(s: &str) -> Result<Self, ParseBucketSetError>
pub fn try_from_str(s: &str) -> Result<Self, ParseBucketSetError>
Parse a BucketSet from its raw textual representation.
Sourcepub fn observe_all(&mut self, value: Point, count: u64)
pub fn observe_all(&mut self, value: Point, count: u64)
Sourcepub fn remap(&mut self, map: impl FnMut(Point) -> Point)
pub fn remap(&mut self, map: impl FnMut(Point) -> Point)
Remap and merge buckets.
This method can be used to rescale the buckets to a coarser granularity in combination with the crate::metric::exp::midpoint function. It accepts a closure that maps stored bucket Points to new values. When multiple buckets map to the same new value, their counts will be summed.
Panics
This method will panic if adding count to an existing entry in value would overflow. This can happen when merging buckets with large counts.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Get the number of buckets currently in the set.
This is not the total count of observed values in all buckets, just the count of buckets themselves. See BucketSet::total for the total count.