pub struct ThreadLocalCtxt { /* private fields */ }Expand description
A Ctxt that stores ambient state in thread local storage.
Frames fully encapsulate all properties that were active when they were created so can be sent across threads to move that state with them.
Implementations
Sourceimpl ThreadLocalCtxt
impl ThreadLocalCtxt
Create a new thread local store sharing the same storage as any other ThreadLocalCtxt::shared.