The Props type.
Properties, also called attributes in some systems, are the structured data associated with an crate::event::Event. They are the dimensions an event can be categorized and queried on. Each property is a pair of Str and Value that can be inspected or serialized.
Props allow duplicate keys, but can be de-duplicated by taking the first value seen for a given key. This lets consumers searching for a key short-circuit once they see it instead of needing to scan to the end in case a duplicate is found.
Props can be fed to a crate::template::Template to render it into a user-facing message.
Well-known properties described in crate::well_known are used to extend emit’s event model with different kinds of diagnostic data.
Structs
- AsMap
- The result of calling
Props::as_map. - Dedup
- The result of calling
Props::dedup. - Filter
- The result of calling
Props::filter. - Owned
Props - A set of owned
Props.