pub struct OwnedProps { /* private fields */ }Expand description
A set of owned Props.
Properties are deduplicated, but the original iteration order is retained. If the collection is created from OwnedProps::collect_shared then cloning is also cheap.
Implementation details
Internally, OwnedProps is backed by a hashtable to make key lookup efficient. Each entry in the table also forms a linked list in iteration order.
The hash algorithm used is FNV-1a.
Implementations
Sourceimpl OwnedProps
impl OwnedProps
Sourcepub fn collect_owned(props: impl Props) -> OwnedProps
pub fn collect_owned(props: impl Props) -> OwnedProps
Collect a set of Props into an owned collection.
Cloning will involve cloning the collection.
Collect a set of Props into an owned collection.
Cloning will involve cloning the Arc, which may be cheaper than cloning the collection itself.
Get a new collection, taking an owned copy of the data in this one.
If the collection already contains an Arc value then this method is a cheap referenced counted clone.