The Span type.
Re-exports
pub use self::completion::Completion;
Modules
- completion
- The
Completiontype.
Structs
- Parse
IdError - An error encountered attempting to parse a
TraceIdorSpanId. - Parse
Kind Error - An error encountered attempting to parse a
TraceIdorSpanId. - Parse
Link Error - An error encountered attempting to parse a
TraceIdorSpanId. - Span
- A diagnostic event that represents a span in a distributed trace.
- Span
Ctxt - The trace id, span id, and parent span id of a span.
- Span
Guard - An active span in a distributed trace.
- SpanId
- A W3C Span Id.
- Span
Link - A link between two spans in potentially different traces.
- TraceId
- A W3C Trace Id.
Enums
- Span
Kind - A hint about the way a span and its child are linked.