emit::span

Struct Span

pub struct Span<'a, P> { /* private fields */ }
A diagnostic event that represents a span in a distributed trace.

Spans are an extension of Events that explicitly take the well-known properties that signal an event as being a span. See the crate::span module for details.

A SpanEvent can be converted into an Event through its ToEvent implemenation, or passed directly to a crate::Emitter to emit it.

Implementations

Source

impl<'a, P: Props> Span<'a, P>

pub fn new( mdl: impl Into<Path<'a>>, name: impl Into<Str<'a>>, extent: impl ToExtent, props: P, ) -> Self

Create a new span event from its parts.

Each span consists of:

  • mdl: The module that executed the operation the span is tracking.
  • name: The name of the operation the span is tracking.
  • extent: The time the operation spent executing. The extent should be a span.
  • props: Additional Props to associate with the span. These may include the SpanCtxt with the trace and span ids for the span, or they may be part of the ambient context.
pub fn mdl(&self) -> &Path<'a>

Get the module that executed the operation.

pub fn with_mdl(self, mdl: impl Into<Path<'a>>) -> Self

Set the module of the span.

pub fn name(&self) -> &Str<'a>

Get the name of the operation.

pub fn with_name(self, name: impl Into<Str<'a>>) -> Self

Set the name of the span.

pub fn extent(&self) -> Option<&Extent>

Get the time the operation spent executing.

pub fn with_extent(self, extent: impl ToExtent) -> Self

Set the extent of the span.

pub fn ts(&self) -> Option<&Timestamp>

Get the extent of the metric as a point in time.

If the span has an extent then this method will return Some, with the result of Extent::as_point. If the span doesn’t have an extent then this method will return None.

pub fn ts_start(&self) -> Option<&Timestamp>

Get the start point of the extent of the span.

If the span has an extent, and that extent covers a timespan then this method will return Some. Otherwise this method will return None.

pub fn props(&self) -> &P

Get the additional properties associated with the span.

pub fn with_props<U>(self, props: U) -> Span<'a, U>

Set the properties of the span.

pub fn map_props<U>(self, map: impl FnOnce(P) -> U) -> Span<'a, U>

Map the properties of the span.

pub fn tpl(&self) -> &Template<'a>

Get the template that will be used to render the span.

pub fn with_tpl(self, tpl: impl Into<Template<'a>>) -> Self

Set the template of the span.

pub fn erase<'b>(&'b self) -> Span<'b, &'b dyn ErasedProps>

Get a type-erased span, borrowing data from this one.