pub struct OwnedValue(/* private fields */);Expand description
An owned Value that can be cloned and shared.
Owned values don’t expose much API of their own but can be cheaply converted back into a Value through OwnedValue::by_ref.
Implementations